ProcessHandleInfo

Struct ProcessHandleInfo 

pub struct ProcessHandleInfo<'a, P: Process + ?Sized> {
    pub handle: Handle,
    pub access: u32,
    pub object_type: u32,
    pub count: usize,
    pub pointer_count: usize,
    pub attributes: u32,
    /* private fields */
}
Represents a handle that a process has opened.

Fields

handle: Handle

The value of the handle.

access: u32

The raw access mask of the object handle.

object_type: u32

The type identifier of the object

count: usize

The number of references to the handle.

pointer_count: usize

The number of pointers to the handle.

attributes: u32

The attributes of the handle.

Implementations

Source

impl<'a, P: Process> ProcessHandleInfo<'a, P>

pub fn duplicate_handle(&self, access: Option<u32>) -> Result<Handle>

Duplicates the handle.

Access Rights

This method requires an object access mask beyond standard bounds like process access and thread access. Therefore, the desired access has been kept in its raw state as a u32. However, if the access is None, it will copy the handle’s original access mask.

pub fn name(&self) -> Result<String>

Retrieves the name of the object, if present.

The name can include path separators (“\”).

pub fn type_name(&self) -> Result<String>

Retrieves the type name of the object.