pub struct ProcessHandleInfo<'a, P: Process + ?Sized> {
pub handle: Handle,
pub access: u32,
pub object_type: u32,
pub count: usize,
pub pointer_count: usize,
pub attributes: u32,
/* private fields */
}Expand description
Represents a handle that a process has opened.
Fields
handle: HandleThe value of the handle.
access: u32The raw access mask of the object handle.
object_type: u32The type identifier of the object
count: usizeThe number of references to the handle.
pointer_count: usizeThe number of pointers to the handle.
attributes: u32The attributes of the handle.
Implementations
Sourceimpl<'a, P: Process> ProcessHandleInfo<'a, P>
impl<'a, P: Process> ProcessHandleInfo<'a, P>
Sourcepub fn duplicate_handle(&self, access: Option<u32>) -> Result<Handle>
pub fn duplicate_handle(&self, access: Option<u32>) -> Result<Handle>
Duplicates the handle.
Access Rights
This method requires an object access mask beyond standard bounds
like process access and thread access. Therefore, the desired access
has been kept in its raw state as a u32. However, if the access is
None, it will copy the handle’s original access mask.